# This script validates that a field has a certain value
# Set Parameter 1 to the field name - eg CODESTTE for the State on the AR Customer screen
# Set Parameter 2, 3, and 4 to the allowed values (comma separated) - eg NSW,TAS,QLD
# If a blank value is allowed then include <BLANK> in the list - eg <BLANK>,NSW,TAS,QLD
#
#
# Copyright 2022 Orchid Systems
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an as is basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure that it is operating as required.

from accpac import *

# onOpen is called when the view is opened.
# Return Continue to enable the macro.
# Return 0 to disable the macro.
# If you return anything else then the view will not load.
def onOpen():
	global fieldDesc
	global allowed

	fieldDesc = me.fieldByName(Parameter1).desc
	allowed = "," + Parameter2 + "," + Parameter3 + "," + Parameter4 + ","
	allowed = allowed.upper()
	return Continue

def onBeforeInsert():
	return Validate()

def onBeforeUpdate():
	return Validate()

#def onBeforePut(e):
#
# If you want the error message to display as you tab off the required field, 
# uncomment this section.  But it does assume that
#   1.  The UI does a "put" into the view field
#   2.  That the UI displayes the resulting error stack.  AR0024 does does do a put to the CODESTTE field, but the UI does not display the message
#
#	if e.field.upper() == Parameter1.upper():
#		return Validate(e.value)
#	return Continue

def Validate(v=None):
	if v == None:
		v = me.get(Parameter1)
	if v == "":
		if ",<BLANK>," in allowed:
			return Continue
	elif "," + v.upper() + "," in allowed:
		return Continue
	error("'" + v + "' is not a valid value for " + fieldDesc)
	return 1
